baseUrl property

String get baseUrl

baseUrl defines the URL of the endpoint to interact with the comm interface. This URL is built with the server and the version.

Implementation

String get baseUrl => 'https://$_baseUrl/${version.value}';