getCommands method
getCommands ask to the server if there are commands to execute.
Implementation
HttpPacketResponse getCommands() async {
final response = await _dio.get('/commands');
return _processResponse(response);
}
getCommands ask to the server if there are commands to execute.
HttpPacketResponse getCommands() async {
final response = await _dio.get('/commands');
return _processResponse(response);
}