sendData method
sendData sends a plain message to the Layrz ecosystem.
Implementation
HttpPacketResponse sendData(ClientPacket message) async => _sendToLayrz(message);
sendData sends a plain message to the Layrz ecosystem.
HttpPacketResponse sendData(ClientPacket message) async => _sendToLayrz(message);