clients/tcp library

Enums

FirmwareBranch
LayrzProtocolMode
LayrzProtocolMode defines the protocol to use.
LayrzProtocolVersion
LayrzProtocolVersion defines the version of the protocol.

Typedefs

BlackboxFetchCallback = Future<List<String>> Function()
Callback invoked on reconnect to retrieve all queued packets. The consumer should return the stored packets and clear their store.
BlackboxStoreCallback = Future<void> Function(String packet)
Callback invoked when the socket is disconnected and a packet needs to be queued. The consumer is responsible for persisting packet for later replay.