BlackboxFetchCallback typedef

BlackboxFetchCallback = Future<List<String>> Function()

Callback invoked on reconnect to retrieve all queued packets. The consumer should return the stored packets and clear their store.

Implementation

typedef BlackboxFetchCallback = Future<List<String>> Function();