BlackboxStoreCallback typedef

BlackboxStoreCallback = Future<void> Function(String packet)

Callback invoked when the socket is disconnected and a packet needs to be queued. The consumer is responsible for persisting packet for later replay.

Implementation

typedef BlackboxStoreCallback = Future<void> Function(String packet);