AbPacket class

Inheritance

Constructors

AbPacket({required List<BleData> devices})
AbPacket is the device list packet.

Properties

devices → List<BleData>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<BleData>? devices}) → AbPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() → String
toPacket returns the packet in the format of Layrz Link Protocol v2.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) → AbPacket
fromPacket creates a AbPacket from a string packet in the format of Layrz Protocol v3.
override