AbPacket constructor

AbPacket({
  1. required List<BleData> devices,
})

AbPacket is the device list packet.

This packet is part of the packet sent from the server to the device.

Implementation

AbPacket({
  /// [devices] is the list of devices that are being ACKed.
  /// This is identified in the packet as `BLE+DATA`
  required this.devices,
}) : super();