AcPacket class

Inheritance

Constructors

AcPacket({required List<Command> commands})
AcPacket is the error ACK packet.

Properties

commands → List<Command>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<Command>? commands}) → AcPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() → String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) → AcPacket
fromPacket creates a AcPacket from a string packet in the format of Layrz Protocol v3.
override