AoPacket class
- Inheritance
-
- Object
- Packet
- ServerPacket
- AoPacket
Properties
Methods
-
copyWith(
{DateTime? timestamp}) → AoPacket -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPacket(
) → String -
toPacket returns the packet in the format of
Layrz Protocol v3.override -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromPacket(
String raw) → AoPacket -
fromPacket creates a AoPacket from a string packet in the format of
Layrz Protocol v3.override