ArPacket class

Inheritance

Constructors

ArPacket({required String reason})
ArPacket is the error ACK packet.

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? reason}) → ArPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() → String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) → ArPacket
fromPacket creates a ArPacket from a string packet in the format of Layrz Protocol v3.
override