AsPacket constructor
AsPacket()
AsPacket is the authentication success packet.
This packet is part of the packet sent from the server to the device.
Implementation
AsPacket() : super();
AsPacket is the authentication success packet.
This packet is part of the packet sent from the server to the device.
AsPacket() : super();