AuPacket class

Inheritance
Annotations
  • @Deprecated('This packet is deprecated and will be removed in v4.0')

Constructors

AuPacket()
AuPacket is the authentication request packet.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() AuPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) AuPacket
fromPacket creates a AuPacket from a string packet in the format of Layrz Protocol v3.
override