macAddress property
macAddress is the detected Mac Address. This Mac Adress came from the detected device, not the device that is detecting.
Implementation
final String macAddress;
macAddress is the detected Mac Address. This Mac Adress came from the detected device, not the device that is detecting.
final String macAddress;