manufacturerData property
manufacturerData is the list of manufacturer data advertised by the device.
Implementation
List<BleManufacturerData> manufacturerData;
manufacturerData is the list of manufacturer data advertised by the device.
List<BleManufacturerData> manufacturerData;