model property

String model
final

model is the model of the detected device. This model should be equals to the model of the device and the model defined by Layrz.

Implementation

final String model;