BleData class

Constructors

BleData({required String macAddress, required String model})
BleData is the BLE data packet.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
macAddress → String
macAddress is the detected Mac Address. This Mac Adress came from the detected device, not the device that is detecting.
final
model → String
model is the model of the detected device. This model should be equals to the model of the device and the model defined by Layrz.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() → String
toPacket converts the BleData to a raw message following this structure: MAC_ADDRESS:MODEL
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromPackets(String raw) → List<BleData>
fromPackets creates a List<BleData> from a raw message following this structure: MAC_ADDRESS:MODEL