BleManufacturerData class

Available extensions

Constructors

BleManufacturerData({required int companyId, required List<int> data})
const

Properties

companyId int
final
data List<int>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() String

Available on BleManufacturerData, provided by the LayrzProtocolManufacturerDataSpec extension

toPacket converts the BleManufacturerData to a raw message following this structure: MANUFACTURER_ID:DATA
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited