BleServiceData class

Available extensions

Constructors

BleServiceData({required int uuid, required List<int> data})
const

Properties

data → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() → String

Available on BleServiceData, provided by the LayrzProtocolServiceDataSpec extension

toPacket converts the BleServiceData to a raw message following this structure: SERVICE_UUID:DATA
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited