ImPacket class

Inheritance

Constructors

ImPacket({required DateTime timestamp, required String chatId, required String message})
ImPacket is the chat message packet

Properties

chatId → String
chatId is the unique identifier for the chat. This is identified in the packet as CHAT_ID
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
message is the chat message content. This is identified in the packet as MESSAGE
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
timestamp is the time of the packet. This is identified in the packet as UNIX
final

Methods

copyWith({DateTime? timestamp, String? chatId, String? message}) → ImPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() → String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) → ImPacket
fromPacket creates a ImPacket from a string packet in the format of Layrz Protocol v3.
override