PaPacket class

Inheritance

Constructors

PaPacket({required String ident, required String password})
PaPacket is authentication packet. Only used over TCP connections.

Properties

hashCode → int
The hash code for this object.
no setterinherited
ident → String
ident is the Unique identifier, sent as part of the packet as IMEI
final
password → String
password is the password of the device.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? ident, String? password}) → PaPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() → String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) → PaPacket
fromPacket creates a PaPacket from a string packet in the format of Layrz Protocol v3.
override