PbPacket class

Inheritance

Constructors

PbPacket({required List<BleAdvertisement> advertisements})
PbPacket is the Bluetooth Low Energy Detection packet. This packet is sent by the device to the server.

Properties

advertisements List<BleAdvertisement>
advertisements is the list of advertisements detected by the device.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<BleAdvertisement>? advertisements}) PbPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) PbPacket
fromPacket creates a PbPacket from a string packet in the format of Layrz Protocol v3.
override