advertisements property
advertisements is the list of advertisements detected by the device.
Implementation
final List<BleAdvertisement> advertisements;
advertisements is the list of advertisements detected by the device.
final List<BleAdvertisement> advertisements;