PcPacket class

Inheritance

Constructors

PcPacket({required DateTime timestamp, required int commandId, required String message})
PcPacket is the command ACK packet.

Properties

commandId → int
commandId is the command ID that is being ACKed. This is identified in the packet as CMD_ID
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
message is the message of the ACK. This is identified in the packet as MSG
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
timestamp is the time of the packet. This is identified in the packet as UNIX
final

Methods

copyWith({DateTime? timestamp, int? commandId, String? message}) → PcPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() → String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) → PcPacket
fromPacket creates a PcPacket from a string packet in the format of Layrz Protocol v3.
override