PdPacket constructor

PdPacket({
  1. required DateTime timestamp,
  2. required Position position,
  3. required Map<String, dynamic> extra,
})

PdPacket is the data packet.

This packet is part of the packet sent from the device to the server.

This packet should be sent passively by the device.

Implementation

PdPacket({
  required this.timestamp,
  required this.position,
  required this.extra,
});