position property

Position position
final

position is the position of the packet. This is identified in the packet as LAT, LON, ALT, SPD, DIR, SAT and HDOP

  • LAT is the latitude of the packet.
  • LON is the longitude of the packet.
  • ALT is the altitude of the packet.
  • SPD is the speed of the packet.
  • DIR is the direction of the packet.
  • SAT is the number of satellites of the packet.
  • HDOP is the HDOP of the packet.

All of the above values are in the packet separated by ; and may be empty.

Implementation

final Position position;