PiPacket class

Inheritance

Constructors

PiPacket({required String ident, required String firmwareId, required int firmwareBuild, required String deviceId, required String hardwareId, required String modelId, required FirmwareBranch firmwareBranch, required bool fotaEnabled})
PiPacket is the identification packet.

Properties

deviceId → String
deviceId is the device internal ID, this is in newer versions is a Layrz ID, otherwise is a unique identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet as SYS_DEV_ID
final
firmwareBranch → FirmwareBranch
firmwareBranch is the branch of the firmware, this is identified in the packet as SYS_DEV_FW_BRANCH
final
firmwareBuild → int
firmwareBuild is the firmware version, is an incremental number that is increased in each release. This is identified in the packet as FW_BUILD
final
firmwareId → String
firmwareId is the firmware internal ID, this is in newer versions is a Layrz ID, otherwise is a unique identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet as FW_ID
final
fotaEnabled → bool
fotaEnabled is a boolean that indicates if the device is capable of receiving FOTA updates. This is identified in the packet as FOTA_ENABLED
final
hardwareId → String
hardwareId is the hardware internal ID, this is in newer versions is a Layrz ID, otherwise is a unique identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet as SYS_DEV_HW_ID
final
hashCode → int
The hash code for this object.
no setterinherited
ident → String
ident is the Unique identifier, sent as part of the packet as IMEI
final
modelId → String
modelId is the model internal ID, this is in newer versions is a Layrz ID, otherwise is a unique identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet as SYS_DEV_MODEL_ID
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? ident, String? firmwareId, int? firmwareBuild, String? deviceId, String? hardwareId, String? modelId, FirmwareBranch? firmwareBranch, bool? fotaEnabled}) → PiPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() → String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) → PiPacket
fromPacket creates a PiPacket from a string packet in the format of Layrz Protocol v3.
override