PiPacket constructor

PiPacket({
  1. required String ident,
  2. required String firmwareId,
  3. required int firmwareBuild,
  4. required String deviceId,
  5. required String hardwareId,
  6. required String modelId,
  7. required FirmwareBranch firmwareBranch,
  8. required bool fotaEnabled,
})

PiPacket is the identification packet.

This packet is part of the packet sent from the device to the server.

This packet should be sent when the device starts up or the get_info command is received.

Implementation

PiPacket({
  required this.ident,
  required this.firmwareId,
  required this.firmwareBuild,
  required this.deviceId,
  required this.hardwareId,
  required this.modelId,
  required this.firmwareBranch,
  required this.fotaEnabled,
});