firmwareBranch property
firmwareBranch is the branch of the firmware, this is identified in the packet as SYS_DEV_FW_BRANCH
Implementation
final FirmwareBranch firmwareBranch;
firmwareBranch is the branch of the firmware, this is identified in the packet as SYS_DEV_FW_BRANCH
final FirmwareBranch firmwareBranch;