firmwareBuild property
firmwareBuild is the firmware version, is an incremental number that is increased in each release.
This is identified in the packet as FW_BUILD
Implementation
final int firmwareBuild;
firmwareBuild is the firmware version, is an incremental number that is increased in each release.
This is identified in the packet as FW_BUILD
final int firmwareBuild;