fotaEnabled property
fotaEnabled is a boolean that indicates if the device is capable of receiving FOTA updates.
This is identified in the packet as FOTA_ENABLED
Implementation
final bool fotaEnabled;
fotaEnabled is a boolean that indicates if the device is capable of receiving FOTA updates.
This is identified in the packet as FOTA_ENABLED
final bool fotaEnabled;