hardwareId property

String hardwareId
final

hardwareId is the hardware internal ID, this is in newer versions is a Layrz ID, otherwise is a unique identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet as SYS_DEV_HW_ID

Implementation

final String hardwareId;