modelId property
modelId is the model internal ID, this is in newer versions is a Layrz ID, otherwise is a unique
identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet
as SYS_DEV_MODEL_ID
Implementation
final String modelId;