PmPacket class

Inheritance

Constructors

PmPacket({required String filename, required String contentType, required Uint8List data})
PmPacket is the media packet.

Properties

contentType String
contentType is the content type of the file.
getter/setter pair
data Uint8List
data is the content of the file.
getter/setter pair
filename String
filename is the name of the file.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? filename, String? contentType, Uint8List? data}) PmPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) PmPacket
fromPacket creates a PmPacket from a string packet in the format of Layrz Protocol v3.
override