PmPacket constructor
PmPacket is the media packet.
This packet is part of the packet sent from the server to the device.
Implementation
PmPacket({
required this.filename,
required this.contentType,
required this.data,
}) : super();
PmPacket is the media packet.
This packet is part of the packet sent from the server to the device.
PmPacket({
required this.filename,
required this.contentType,
required this.data,
}) : super();