satellites property
satellites is the number of satellites. This value should be greater than or equals to 0.
Implementation
final int? satellites;
satellites is the number of satellites. This value should be greater than or equals to 0.
final int? satellites;