PrPacket constructor
PrPacket()
PrPacket is the authentication success packet.
This packet is part of the packet sent from the server to the device.
Implementation
PrPacket() : super();
PrPacket is the authentication success packet.
This packet is part of the packet sent from the server to the device.
PrPacket() : super();