PsPacket class

Inheritance

Constructors

PsPacket({required DateTime timestamp, required Map<String, dynamic> params})
PsPacket is the configuration packet.

Properties

hashCode int
The hash code for this object.
no setterinherited
params Map<String, dynamic>
params is the configuration parameters of the packet. This is identified in the packet as EXTRA+ARGS
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
timestamp is the time of the packet. This is identified in the packet as UNIX
final

Methods

copyWith({DateTime? timestamp, Map<String, dynamic>? params}) PsPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) PsPacket
fromPacket creates a PsPacket from a string packet in the format of Layrz Protocol v3.
override