PsPacket constructor

PsPacket({
  1. required DateTime timestamp,
  2. required Map<String, dynamic> params,
})

PsPacket is the configuration packet.

This packet is part of the packet sent from the device to the server.

Also, this packet only will be sent when get_config or set_config command is received.

Implementation

PsPacket({
  required this.timestamp,
  required this.params,
});