distanceTraveled property
distanceTraveled is the distance traveled during the trip in meters.
This is identified in the packet as DISTANCE_TRAVELED
Implementation
final double distanceTraveled;
distanceTraveled is the distance traveled during the trip in meters.
This is identified in the packet as DISTANCE_TRAVELED
final double distanceTraveled;