TsPacket class

Inheritance

Constructors

TsPacket({required DateTime timestamp, required String tripId})
TsPacket is the Trip start packet.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
timestamp is the time of the packet. This is identified in the packet as UNIX
final
tripId String
tripId is the trip identifier of the packet. This is identified in the packet as TRIP_ID
final

Methods

copyWith({DateTime? timestamp, String? tripId}) TsPacket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPacket() String
toPacket returns the packet in the format of Layrz Protocol v3.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPacket(String raw) TsPacket
fromPacket creates a TsPacket from a string packet in the format of Layrz Protocol v3.
override