HttpServer class

Constructors

HttpServer(HttpConfig cfg)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
port → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serve() → Future<void>
start() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited