TcpConfig class

Constructors

TcpConfig({required int port, required TcpOnNewPacket onNewPacket, TcpOnDecodeError? onDecodeError, bool proxyProtocolV2 = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onDecodeError TcpOnDecodeError?
final
onNewPacket TcpOnNewPacket
final
port int
final
proxyProtocolV2 bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited