LayrzProtocolMode enum

LayrzProtocolMode defines the protocol to use.

Please, read each mode to understand the differences between them.

Inheritance
Available extensions

Values

tcp → const LayrzProtocolMode

tcp defines the protocol to use TCP.

http → const LayrzProtocolMode

http defines the protocol to use HTTP.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromString(String value) → LayrzProtocolMode

Constants

values → const List<LayrzProtocolMode>
A constant List of the values in this enum, in order of their declaration.