LayrzProtocolVersion enum

LayrzProtocolVersion defines the version of the protocol.

Inheritance
Available extensions

Values

v2 → const LayrzProtocolVersion

v2 is the version 2 of the protocol. Enhances capabilities like commands, images, and BLE devices.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromString(String value) → LayrzProtocolVersion

Constants

values → const List<LayrzProtocolVersion>
A constant List of the values in this enum, in order of their declaration.