AcPacket constructor
AcPacket is the error ACK packet.
This packet is part of the packet sent from the server to the device.
Implementation
AcPacket({
/// [commands] is the list of commands that are being ACKed.
/// This is identified in the packet as `CMD+DEFINITION`
required this.commands,
}) : super();