AoPacket constructor
AoPacket({
- required DateTime timestamp,
AoPacket is the ACK packet.
This packet is part of the packet sent from the server to the device.
Specifically, this packet is sent when the server doesn't have commands waiting for the device.
Implementation
AoPacket({
/// [messageId] is the message ID that is being ACKed.
/// This is identified in the packet as `MSG_ID`
required this.timestamp,
}) : super();