AuPacket constructor
AuPacket is the authentication request packet.
This packet is part of the packet sent from the server to the device.
Implementation
@Deprecated('This packet is deprecated and will be removed in v4.0')
AuPacket() : super();
AuPacket is the authentication request packet.
This packet is part of the packet sent from the server to the device.
@Deprecated('This packet is deprecated and will be removed in v4.0')
AuPacket() : super();