Packet class
- Implementers
Constructors
- Packet()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
) → Packet -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPacket(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertToDotCase(
String key, dynamic value) → Map< String, dynamic> -
decodeClientPacket(
String raw) → ClientPacket -
decodeServerPacket(
String raw) → ServerPacket -
fromPacket(
String raw) → Packet -
parseExtraArgs(
String raw) → Map< String, dynamic>