PbPacket constructor
PbPacket({
- required List<
BleAdvertisement> advertisements,
PbPacket is the Bluetooth Low Energy Detection packet. This packet is sent by the device to the server.
This packet is part of the Layrz Global Network, a new initiative to create
a global network of devices, anywhere, anytime.
Implementation
PbPacket({required this.advertisements});