PcPacket constructor
PcPacket is the command ACK packet.
This packet is part of the packet sent from the device to the server.
This packet should be send after the execution of a command, received in Ac packet.
Implementation
PcPacket({
required this.timestamp,
required this.commandId,
required this.message,
});