PdPacket class
- Inheritance
-
- Object
- Packet
- ClientPacket
- PdPacket
Constructors
Properties
-
extra
→ Map<
String, dynamic> -
extra is the extra data of the packet.
This is identified in the packet as
EXTRA+ARGS.final - hashCode → int
-
The hash code for this object.
no setterinherited
- position → Position
-
position is the position of the packet.
This is identified in the packet as
LAT,LON,ALT,SPD,DIR,SATandHDOPfinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
timestamp is the time of the packet.
This is identified in the packet as
UNIXfinal
Methods
-
copyWith(
{DateTime? timestamp, Position? position, Map< String, dynamic> ? extra}) → PdPacket -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPacket(
) → String -
toPacket returns the packet in the format of
Layrz Protocol v3.override -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromPacket(
String raw) → PdPacket -
fromPacket creates a PdPacket from a string packet in the format of
Layrz Protocol v3.override