deviceId is the device internal ID, this is in newer versions is a Layrz ID, otherwise is a unique
identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet as SYS_DEV_ID
firmwareId is the firmware internal ID, this is in newer versions is a Layrz ID, otherwise is a unique
identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet as FW_ID
hardwareId is the hardware internal ID, this is in newer versions is a Layrz ID, otherwise is a unique
identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet as SYS_DEV_HW_ID
modelId is the model internal ID, this is in newer versions is a Layrz ID, otherwise is a unique
identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet
as SYS_DEV_MODEL_ID