firmwareId property
firmwareId is the firmware internal ID, this is in newer versions is a Layrz ID, otherwise is a unique
identifier set by the hardware department of Layrz LTD. Also, is idenfified in the packet as FW_ID
Implementation
final String firmwareId;