Position class

Constructors

Position({double? latitude, double? longitude, double? altitude, double? speed, double? direction, int? satellites, double? hdop})
Position is the definition of the position. This class is used to send the position to the Layrz ecosystem.

Properties

altitude double?
altitude is the altitude of the position.
final
direction double?
direction is the direction of the position. This value should be between 0 and 360.
final
hashCode int
The hash code for this object.
no setterinherited
hdop double?
hdop is the horizontal dilution of precision. This value should be greater than or equals to 0.
final
latitude double?
latitude is the latitude of the position. This value should be between -90 and 90.
final
longitude double?
longitude is the longitude of the position. This value should be between -180 and 180.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satellites int?
satellites is the number of satellites. This value should be greater than or equals to 0.
final
speed double?
speed is the speed of the position. This value should be greater than or equals to 0.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited