TePacket class
Properties
-
distanceTraveled
→ double
-
distanceTraveled is the distance traveled during the trip in meters.
This is identified in the packet as
DISTANCE_TRAVELED
final
-
duration
→ Duration
-
duration is the duration of the trip in seconds.
This is identified in the packet as
DURATION
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
maxSpeed
→ double
-
maxSpeed is the maximum speed during the trip in km/h.
This is identified in the packet as
MAX_SPEED
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
timestamp
→ DateTime
-
timestamp is the time of the packet.
This is identified in the packet as
UNIX
final
-
tripId
→ String
-
tripId is the trip identifier of the packet.
This is identified in the packet as
TRIP_ID
final