HttpConfig class
Constructors
- HttpConfig({required int port, required HttpOnNewPacket onNewPacket, HttpOnPullCommands? onPullCommands, HttpOnAuthenticate? onAuthenticate, HttpOnDecodeError? onDecodeError, int maxBodyBytes = 1 << 20, Duration shutdownTimeout = const Duration(seconds: 5)})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxBodyBytes → int
-
final
- onAuthenticate → HttpOnAuthenticate?
-
final
- onDecodeError → HttpOnDecodeError?
-
final
- onNewPacket → HttpOnNewPacket
-
final
- onPullCommands → HttpOnPullCommands?
-
final
- port → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shutdownTimeout → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited